@@ -19,8 +19,8 @@
 ;; Keywords: languages, debug
 ;; URL: https://github.com/emacs-lsp/dap-mode
 ;; Package-Requires: ((emacs "28.1") (dash "2.18.0") (lsp-mode "6.0") (bui "1.1.0") (f "0.20.0") (s "1.12.0") (lsp-treemacs "0.1") (posframe "0.7.0") (ht "2.3") (lsp-docker "1.0.0"))
-;; Package-Version: 20260104.1524
-;; Package-Revision: ded79ff0637f
+;; Package-Version: 20260208.1403
+;; Package-Revision: b77d9bdb15d8
 
 ;;; Commentary:
 ;; Debug Adapter Protocol client for Emacs.
@@ -1283,14 +1283,17 @@ ADAPTER-ID the id of the adapter."
     debug-session))
 
 (defun dap--send-configuration-done (debug-session)
-  "Send `configurationDone' message for DEBUG-SESSION."
-  (dap--send-message (dap--make-request "configurationDone")
-                     (dap--resp-handler
-                      (lambda (_)
-                        (when (eq 'pending (dap--debug-session-state debug-session))
-                          (setf (dap--debug-session-state debug-session) 'running)
-                          (run-hook-with-args 'dap-session-changed-hook))))
-                     debug-session))
+  "Send `configurationDone' message for DEBUG-SESSION if supported by server."
+  (let ((callback (lambda (_)
+                    (when (eq 'pending (dap--debug-session-state debug-session))
+                      (setf (dap--debug-session-state debug-session) 'running)
+                      (run-hook-with-args 'dap-session-changed-hook)))))
+    (if (gethash "supportsConfigurationDoneRequest" (dap--debug-session-current-capabilities (dap--cur-session)))
+        (dap--send-message (dap--make-request "configurationDone")
+                           (dap--resp-handler
+                            callback)
+                           debug-session)
+      (funcall callback 'ok))))
 
 (defun dap--set-breakpoints-request (debug-session file-name file-breakpoints)
   "Make `setBreakpoints' request for FILE-NAME.
